grib2io.tables.section0 API documentation

# grib2io.tables.section0

View Source

     1table_0_0 = {
     2'0':'Meteorological Products',
     3'1':'Hydrological Products',
     4'2':'Land Surface Products',
     5'3':'Satellite Remote Sensing Products',
     6'4':'Space Weather Products',
     7'5-9':'Reserved',
     8'10':'Oceanographic Products',
     9'11-19':'Reserved',
    10'20':'Health and Socioeconomic Impacts',
    11'21-191':'Reserved',
    12'192-254':'Reserved for Local Use',
    13'255':'Missing',
    14}